@@ -43,7 +43,8 @@ public:
   Q_INVOKABLE QString transliteratedSuraName(int sura);
   Q_INVOKABLE int pageNumberForSura(int sura);
   Q_INVOKABLE int pageNumberForSuraAndAya(int sura, int aya);
-  Q_INVOKABLE QString partName(int page);
+  Q_INVOKABLE QString partNameForPage(int page);
+  Q_INVOKABLE QString partName(int part);
 
   Q_INVOKABLE int firstSuraForPage(int page);
 
@@ -82,6 +83,8 @@ public:
 
   Q_INVOKABLE int suraSize(int sura);
 
+  QList<Fragment> fragmentsForPart(int part);
+
 private:
   const QString m_dir;
 
